==> knews-0.9.7.tar.gz: knews-0.9.7/src/layouts/post.h <==
"vertical { "
"	8 "
"	posttitle <+inf-inf*> "
"	4 "
"	horizontal { "
"		4 "
"		sash1 <+inf-inf*> "
"		4 "
"	} "
"	4 "
"	horizontal { "
"		8 "
"		posttext <+inf-inf*+inff-inf> "
"		2 "
"		textscrbar <*+inf-inf> "
"		4 "
"	} "
"	4 "
"	horizontal { "
"		4 "
"		sash2 <+inf-inf*> "
"		4 "
"	} "
"	4 "
"	postmessage <+inf-inf*> "
"	4 "
"	horizontal { "
"		4 "
"		sash3 <+inf-inf*> "
"		4 "
"	} "
"	4 "
"	horizontal { "
"		8 <+inf-inf> "
"		post "
"		4 <+inf-inf> "
"		edit "
"		4 <+inf-inf> "
"		misc "
"		4 <+inf-inf> "
"		attach "
"		4 <+inf-inf> "
"		detach "
"		4 <+inf-inf> "
"		cancel "
"		8 <+inf-inf> "
"	} "
"	4 "
"	horizontal { "
"		4 "
"		sash4 <+inf-inf*> "
"		4 "
"	} "
"	4 "
"	attachtitle <+inf-inf*> "
"	4 "
"	horizontal { "
"		8 "
"		vertical { "
"			manager <+inf-inf*+inff-inf> "
"			2 "
"			listhbar <+inf-inf*> "
"		} "
"		2 "
"		vertical { "
"			listvbar <*+inff-inf> "
"			2 "
"			height listhbar "
"		} "
"		4 "
"	} "
"	4 "
"	horizontal { "
"		8 "
"		vertical { "
"			0 <+inf> "
"			typetitle "
"			0 <+inf> "
"		} "
"		((width enctitle - width typetitle - width type)/2) "
"		vertical { "
"			0 <+inf-inf> "
"			type <*-inf> "
"			0 <+inf-inf> "
"		} "
"		((width enctitle - width typetitle - width type)/2) "
"		typefield <+inf-inf*> "
"		4 + width listvbar "
"	} "
"	4 "
"	horizontal { "
"		8 "
"		vertical { "
"			0 <+inf> "
"			enctitle "
"			0 <+inf> "
"		} "
"		2 "
"		nonetoggle "
"		base64toggle "
"		uuetoggle "
"		qptoggle "
"		2 + 4 + width listvbar "
"	} "
"	4 "
"	horizontal { "
"		8 "
"		vertical { "
"			0 <+inf> "
"			descrtitle "
"			0 <+inf> "
"		} "
"		(width enctitle - width descrtitle) "
"		descrfield <+inf-inf*+0-0> "
"		4 + width listvbar "
"	} "
"	4 "
"	horizontal { "
"		8 "
"		vertical { "
"			0 <+inf> "
"			disptitle "
"			0 <+inf> "
"		} "
"		(width enctitle - width disptitle) "
"		2 "
"		vertical { "
"			0 <+inf> "
"			inlinetoggle "
"			0 <+inf> "
"		} "
"		vertical { "
"			0 <+inf> "
"			attachtoggle "
"			0 <+inf> "
"		} "
"		4 "
"		vertical { "
"			0 <+inf> "
"			nametitle "
"			0 <+inf> "
"		} "
"		vertical { "
"			0 <+inf> "
"			namefield <+inf-inff*> "
"			0 <+inf> "
"		} "
"		4 + width listvbar "
"	} "
"	8 "
"} ",

==> knews_0.9.8.orig.tar.gz: knews-0.9.8.orig/src/layouts/post.h <==
"vertical { "
"	8 "
"	posttitle <+inf-inf*> "
"	4 "
"	horizontal { "
"		4 "
"		sash1 <+inf-inf*> "
"		4 "
"	} "
"	4 "
"	horizontal { "
"		8 "
"		posttextmgr <+inf-inf*+inff-inf> "
"		2 "
"		textvbar <*+inf-inf> "
"		4 "
"	} "
"	horizontal { "
"		8 "
"		texthbar <+inf-inf*> "
"		6 + width textvbar "
"	} "
"	4 "
"	horizontal { "
"		4 "
"		sash2 <+inf-inf*> "
"		4 "
"	} "
"	4 "
"	postmessage <+inf-inf*> "
"	4 "
"	horizontal { "
"		4 "
"		sash3 <+inf-inf*> "
"		4 "
"	} "
"	4 "
"	horizontal { "
"		8 <+inf-inf> "
"		post "
"		4 <+inf-inf> "
"		edit "
"		4 <+inf-inf> "
"		misc "
"		4 <+inf-inf> "
"		attach "
"		4 <+inf-inf> "
"		detach "
"		4 <+inf-inf> "
"		cancel "
"		8 <+inf-inf> "
"	} "
"	4 "
"	horizontal { "
"		4 "
"		sash4 <+inf-inf*> "
"		4 "
"	} "
"	4 "
"	attachtitle <+inf-inf*> "
"	4 "
"	horizontal { "
"		8 "
"		vertical { "
"			manager <+inf-inf*+inff-inf> "
"			2 "
"			listhbar <+inf-inf*> "
"		} "
"		2 "
"		vertical { "
"			listvbar <*+inff-inf> "
"			2 "
"			height listhbar "
"		} "
"		4 "
"	} "
"	4 "
"	horizontal { "
"		8 "
"		vertical { "
"			0 <+inf> "
"			typetitle "
"			0 <+inf> "
"		} "
"		((width enctitle - width typetitle - width type)/2) "
"		vertical { "
"			0 <+inf-inf> "
"			type <*-inf> "
"			0 <+inf-inf> "
"		} "
"		((width enctitle - width typetitle - width type)/2) "
"		typefield <+inf-inf*> "
"		4 + width listvbar "
"	} "
"	4 "
"	horizontal { "
"		8 "
"		vertical { "
"			0 <+inf> "
"			enctitle "
"			0 <+inf> "
"		} "
"		2 "
"		nonetoggle "
"		base64toggle "
"		uuetoggle "
"		qptoggle "
"		2 + 4 + width listvbar "
"	} "
"	4 "
"	horizontal { "
"		8 "
"		vertical { "
"			0 <+inf> "
"			descrtitle "
"			0 <+inf> "
"		} "
"		(width enctitle - width descrtitle) "
"		descrfield <+inf-inf*+0-0> "
"		4 + width listvbar "
"	} "
"	4 "
"	horizontal { "
"		8 "
"		vertical { "
"			0 <+inf> "
"			disptitle "
"			0 <+inf> "
"		} "
"		(width enctitle - width disptitle) "
"		2 "
"		vertical { "
"			0 <+inf> "
"			inlinetoggle "
"			0 <+inf> "
"		} "
"		vertical { "
"			0 <+inf> "
"			attachtoggle "
"			0 <+inf> "
"		} "
"		4 "
"		vertical { "
"			0 <+inf> "
"			nametitle "
"			0 <+inf> "
"		} "
"		vertical { "
"			0 <+inf> "
"			namefield <+inf-inff*> "
"			0 <+inf> "
"		} "
"		4 + width listvbar "
"	} "
"	8 "
"} ",
